summaryrefslogtreecommitdiff
path: root/odk/examples
diff options
context:
space:
mode:
Diffstat (limited to 'odk/examples')
-rw-r--r--odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java2
-rw-r--r--odk/examples/DevelopersGuide/Forms/DataAwareness.java4
-rw-r--r--odk/examples/DevelopersGuide/Forms/DocumentBasedExample.java2
-rw-r--r--odk/examples/DevelopersGuide/OfficeBean/OOoBeanViewer.java6
-rw-r--r--odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java2
-rw-r--r--odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java2
-rw-r--r--odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OfficeConnect.java2
-rw-r--r--odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java2
-rw-r--r--odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/ViewContainer.java2
-rw-r--r--odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/FlatXmlFilter_cpp/FlatXml.cxx2
-rw-r--r--odk/examples/DevelopersGuide/OfficeDev/OfficeConnect.java2
-rw-r--r--odk/examples/DevelopersGuide/Text/TextDocuments.java8
-rw-r--r--odk/examples/DevelopersGuide/UCB/ResourceManager.java12
-rw-r--r--odk/examples/java/Storage/Test01.java2
-rw-r--r--odk/examples/java/Storage/Test04.java2
-rw-r--r--odk/examples/java/Storage/Test07.java2
-rw-r--r--odk/examples/java/Storage/Test08.java2
-rw-r--r--odk/examples/java/Storage/Test09.java2
18 files changed, 29 insertions, 29 deletions
diff --git a/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java b/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java
index ed5d63e5305d..422de9f820d7 100644
--- a/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java
+++ b/odk/examples/DevelopersGuide/Components/Addons/JobsAddon/AsyncJob.java
@@ -118,7 +118,7 @@ public class AsyncJob extends WeakBase implements XServiceInfo, XAsyncJob
lDynamicData = (com.sun.star.beans.NamedValue[])com.sun.star.uno.AnyConverter.toArray(lArgs[i].Value);
}
- // Analyze the environment info. This sub list is the only guarenteed one!
+ // Analyze the environment info. This sub list is the only guaranteed one!
if (lEnvironment == null)
throw new com.sun.star.lang.IllegalArgumentException("no environment");
diff --git a/odk/examples/DevelopersGuide/Forms/DataAwareness.java b/odk/examples/DevelopersGuide/Forms/DataAwareness.java
index ca6454f4b9f7..749c8c900195 100644
--- a/odk/examples/DevelopersGuide/Forms/DataAwareness.java
+++ b/odk/examples/DevelopersGuide/Forms/DataAwareness.java
@@ -456,7 +456,7 @@ public class DataAwareness extends DocumentBasedExample implements XPropertyChan
}
/* ------------------------------------------------------------------ */
- /** creates the table witht the given name, using the given statement
+ /** creates the table with the given name, using the given statement
*/
protected boolean implCreateTable( XConnection xConn, String sCreateStatement, String sTableName ) throws java.lang.Exception
{
@@ -855,7 +855,7 @@ public class DataAwareness extends DocumentBasedExample implements XPropertyChan
m_aSalesLocker = new ControlLock( xSalesFormProps, "SALENR" );
m_aSalesLocker.enableLock( m_bProtectKeyFields );
- // initally, we want to generate keys when moving to a new record
+ // initially, we want to generate keys when moving to a new record
xKeyGen.setPropertyValue( "DefaultState", new Short( (short)1 ) );
diff --git a/odk/examples/DevelopersGuide/Forms/DocumentBasedExample.java b/odk/examples/DevelopersGuide/Forms/DocumentBasedExample.java
index 04a4dbc26199..0c3d3a933261 100644
--- a/odk/examples/DevelopersGuide/Forms/DocumentBasedExample.java
+++ b/odk/examples/DevelopersGuide/Forms/DocumentBasedExample.java
@@ -21,7 +21,7 @@ import com.sun.star.util.XCloseable;
public abstract class DocumentBasedExample implements com.sun.star.lang.XEventListener
{
- /// the intial remote context from the office
+ /// the initial remote context from the office
protected XComponentContext m_xCtx;
/// our current test document
protected DocumentHelper m_document;
diff --git a/odk/examples/DevelopersGuide/OfficeBean/OOoBeanViewer.java b/odk/examples/DevelopersGuide/OfficeBean/OOoBeanViewer.java
index 8cc75564ed48..b42f8d5eb362 100644
--- a/odk/examples/DevelopersGuide/OfficeBean/OOoBeanViewer.java
+++ b/odk/examples/DevelopersGuide/OfficeBean/OOoBeanViewer.java
@@ -43,8 +43,8 @@ import java.io.*;
*
* This applet is a sample implementation of the
* OpenOffice.org bean.
- * When initally loaded the applet has two buttons
- * one for opening an existant file and one to open
+ * When initially loaded the applet has two buttons
+ * one for opening an existent file and one to open
* a blank document of a given type supported by
* OpenOffice.org eg. Writer, Calc, Impress, .....
*
@@ -96,7 +96,7 @@ public class OOoBeanViewer extends java.applet.Applet
documentTypePopUp = new javax.swing.JPopupMenu();
storeDocumentButton = new javax.swing.JButton("store to buffer");
loadDocumentButton = new javax.swing.JButton("load from buffer");
- syswinButton = new javax.swing.JButton("release/aquire");
+ syswinButton = new javax.swing.JButton("release/acquire");
menuBarButton = new javax.swing.JCheckBox("MenuBar");
menuBarButton.setSelected( aBean.isMenuBarVisible() );
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java
index a8106c06ffc7..0fb4ecb6c578 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/DocumentView.java
@@ -328,7 +328,7 @@ public class DocumentView extends JFrame
mbDead=true;
// force these sub view to release her remote
- // refrences too!
+ // references too!
maStatusView.shutdown();
maCustomizeView.shutdown();
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
index 0e3851b427ce..43f98d232d83 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/FunctionHelper.java
@@ -695,7 +695,7 @@ public class FunctionHelper
{
// First detect factory of this document.
// Ask for the supported service name of this document.
- // If information is available it can be used to find out wich
+ // If information is available it can be used to find out which
// filter exist for HTML export. Normaly this filter should be searched
// inside the filter configuration but this little demo doesn't do so.
// (see service com.sun.star.document.FilterFactory for further
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OfficeConnect.java b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OfficeConnect.java
index 8b1d4b7a5ce4..d6e0563359ef 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OfficeConnect.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/OfficeConnect.java
@@ -114,7 +114,7 @@ public class OfficeConnect
/**
* create uno components inside remote office process
- * After connection of these proccess to a running office we have access to
+ * After connection of these process to a running office we have access to
* remote service manager of it.
* So we can use it to create all existing services. Use this method to create
* components by name and get her interface. Casting of it to right target
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java
index d9bd18e60320..e75c10a22764 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/StatusListener.java
@@ -124,7 +124,7 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
* for status events. So we can do it automatically. The outside code
* mustn't check such things. We can work with one frame,
* till it die. It doesn't matter if he will be used for different
- * load/save or any other requests. We will be up to date everytime.
+ * load/save or any other requests. We will be up to date every time.
*/
public void startListening()
{
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/ViewContainer.java b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/ViewContainer.java
index ef632f98b0f2..e91eeefb9cde 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/ViewContainer.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/ViewContainer.java
@@ -253,7 +253,7 @@ public class ViewContainer extends Thread
* @member mlListener list of all currently registered shutdown listener
* @member mbShutdownActive if this shutdown hook already was started it's not a good idea to
* call System.exit() again for other conditions.
- * We supress it by using this variable!
+ * We suppress it by using this variable!
*/
public static boolean mbInplace = false ;
private static ViewContainer maSingleton = null ;
diff --git a/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/FlatXmlFilter_cpp/FlatXml.cxx b/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/FlatXmlFilter_cpp/FlatXml.cxx
index bfb662e758f5..83a21003ee57 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/FlatXmlFilter_cpp/FlatXml.cxx
+++ b/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/FlatXmlFilter_cpp/FlatXml.cxx
@@ -194,7 +194,7 @@ sal_Bool XFlatXml::exporter(
{
// read source data
- // we are especialy interested in the output stream
+ // we are especially interested in the output stream
// since that is where our xml-writer will push the data
// from it's data-source interface
OUString aName, sURL;
diff --git a/odk/examples/DevelopersGuide/OfficeDev/OfficeConnect.java b/odk/examples/DevelopersGuide/OfficeDev/OfficeConnect.java
index 6ccb776e1202..faecbe5e6513 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/OfficeConnect.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/OfficeConnect.java
@@ -97,7 +97,7 @@ public class OfficeConnect
/**
* create uno components inside remote office process
- * After connection of these proccess to a running office we have access to remote service manager of it.
+ * After connection of these process to a running office we have access to remote service manager of it.
* So we can use it to create all existing services. Use this method to create components by name and
* get her interface. Casting of it to right target interface is part of your implementation.
*
diff --git a/odk/examples/DevelopersGuide/Text/TextDocuments.java b/odk/examples/DevelopersGuide/Text/TextDocuments.java
index a7db8f494a6b..ab66ebd5f3a8 100644
--- a/odk/examples/DevelopersGuide/Text/TextDocuments.java
+++ b/odk/examples/DevelopersGuide/Text/TextDocuments.java
@@ -501,11 +501,11 @@ public class TextDocuments {
{
try
{
- // Get a text range refering to the beginning of the text document
+ // Get a text range referring to the beginning of the text document
XTextRange xStart = mxDocText.getStart();
// use setString to insert text at the beginning
xStart.setString ( "This is text inserted at the beginning.\n\n" );
- // Get a text range refering to the end of the text document
+ // Get a text range referring to the end of the text document
XTextRange xEnd = mxDocText.getEnd();
// use setString to insert text at the end
xEnd.setString ( "This is text inserted at the end.\n\n" );
@@ -663,7 +663,7 @@ public class TextDocuments {
return ( ( maRandom.nextInt() % 1000 ) * maRandom.nextDouble () );
}
- /** This method sets the text colour of the cell refered to by sCellName to
+ /** This method sets the text colour of the cell referred to by sCellName to
white and inserts the string sText in it
*/
protected static void insertIntoCell(String sCellName, String sText,
@@ -1680,7 +1680,7 @@ public class TextDocuments {
XNamed xSectionNamed = UnoRuntime.queryInterface(XNamed.class,
mxDocFactory.createInstance("com.sun.star.text.TextSection"));
- // Set the name of our new section (appropiately) to 'Fish'
+ // Set the name of our new section (appropriately) to 'Fish'
xSectionNamed.setName ( "Fish" );
// Create the TextColumns service and get its XTextColumns interface
diff --git a/odk/examples/java/Storage/Test01.java b/odk/examples/java/Storage/Test01.java
index 43be8cce1af0..7ff1f4f498bc 100644
--- a/odk/examples/java/Storage/Test01.java
+++ b/odk/examples/java/Storage/Test01.java
@@ -106,7 +106,7 @@ public class Test01 implements StorageTest {
}
// copy xTempStorage to xTempFileStorage
- // xTempFileStorage will be automatically commited
+ // xTempFileStorage will be automatically committed
if ( !m_aTestHelper.copyStorage( xTempStorage, xTempFileStorage ) )
return false;
diff --git a/odk/examples/java/Storage/Test04.java b/odk/examples/java/Storage/Test04.java
index 9be3c528ec8e..89417471afa8 100644
--- a/odk/examples/java/Storage/Test04.java
+++ b/odk/examples/java/Storage/Test04.java
@@ -128,7 +128,7 @@ public class Test04 implements StorageTest {
if ( !m_aTestHelper.copyElementTo( xTempStorage, "SubStorage1", xTempFileStorage ) )
return false;
- // if storage is not commited before disposing all the changes will be lost
+ // if storage is not committed before disposing all the changes will be lost
if ( !m_aTestHelper.commitStorage( xTempSubStorage2 ) )
return false;
diff --git a/odk/examples/java/Storage/Test07.java b/odk/examples/java/Storage/Test07.java
index 4e11fadbc855..ba92f649aafd 100644
--- a/odk/examples/java/Storage/Test07.java
+++ b/odk/examples/java/Storage/Test07.java
@@ -84,7 +84,7 @@ public class Test07 implements StorageTest {
}
// copy xTempStorage to xTempFileStorage
- // xTempFileStorage will be automatically commited
+ // xTempFileStorage will be automatically committed
if ( !m_aTestHelper.copyStorage( xTempStorage, xTempFileStorage ) )
return false;
diff --git a/odk/examples/java/Storage/Test08.java b/odk/examples/java/Storage/Test08.java
index e36780a07aed..6e5aec84b3e0 100644
--- a/odk/examples/java/Storage/Test08.java
+++ b/odk/examples/java/Storage/Test08.java
@@ -139,7 +139,7 @@ public class Test08 implements StorageTest {
}
// copy xTempStorage to xTempFileStorage
- // xTempFileStorage will be automatically commited
+ // xTempFileStorage will be automatically committed
if ( !m_aTestHelper.copyStorage( xTempStorage, xTempFileStorage ) )
return false;
diff --git a/odk/examples/java/Storage/Test09.java b/odk/examples/java/Storage/Test09.java
index 0a8a365eebab..4e7f5f2ba66c 100644
--- a/odk/examples/java/Storage/Test09.java
+++ b/odk/examples/java/Storage/Test09.java
@@ -81,7 +81,7 @@ public class Test09 implements StorageTest {
}
// copy xTempStorage to xTempFileStorage
- // xTempFileStorage will be automatically commited
+ // xTempFileStorage will be automatically committed
if ( !m_aTestHelper.copyStorage( xTempStorage, xTempFileStorage ) )
return false;
diff --git a/odk/examples/DevelopersGuide/UCB/ResourceManager.java b/odk/examples/DevelopersGuide/UCB/ResourceManager.java
index 3ab7bbeecd5b..9e8e2dc6585a 100644
--- a/odk/examples/DevelopersGuide/UCB/ResourceManager.java
+++ b/odk/examples/DevelopersGuide/UCB/ResourceManager.java
@@ -84,7 +84,7 @@ public class ResourceManager {
* This method requires the main and the optional arguments to be set in order to work.
* See Constructor.
*
- *@return boolean Returns true if resource successfully transfered, false otherwise
+ *@return boolean Returns true if resource successfully transferred, false otherwise
*@exception com.sun.star.ucb.CommandAbortedException
*@exception com.sun.star.uno.Exception
*/
@@ -102,8 +102,8 @@ public class ResourceManager {
*
*@param String Source URL
*@param String Target folder URL
*@param String Transfering operation (copy, move, link)
*@return boolean Returns true if resource successfully transfered, false otherwise
*@exception com.sun.star.ucb.CommandAbortedException
*@exception com.sun.star.uno.Exception
*/
@@ -174,9 +174,9 @@ public class ResourceManager {
}
/**
- * Get new title for the resource to be transfered.
+ * Get new title for the resource to be transferred.
*
- *@return String That contains a new title for the transfered
+ *@return String That contains a new title for the transferred
* resource. Can be empty. In this case resource
* will keep the title it has in the source folder.
*/
@@ -268,7 +268,7 @@ public class ResourceManager {
if ( result )
System.out.println( "\nTransfering resource succeeded." );
else
- System.out.println( "Transfering resource failed." );
+ System.out.println( "Transferring resource failed." );
System.out.println( " Source URL : " + sourceURL );
System.out.println( " Target Folder URL : " + targetFolderURL );
@@ -102,8 +102,8 @@ public class ResourceManager {
*@param String Source URL
*@param String Target folder URL
- *@param String Transfering operation (copy, move, link)
- *@return boolean Returns true if resource successfully transfered, false otherwise
+ *@param String Transferring operation (copy, move, link)
+ *@return boolean Returns true if resource successfully transferred, false otherwise
*@exception com.sun.star.ucb.CommandAbortedException
*@exception com.sun.star.uno.Exception